@@ -1,34 +1,34 @@
-providers_version_num <- "1.13.0"
+providers_version_num <- "2.0.0"
 providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "OpenStreetMap.Mapnik", 
     OpenStreetMap.DE = "OpenStreetMap.DE", OpenStreetMap.CH = "OpenStreetMap.CH", 
     OpenStreetMap.France = "OpenStreetMap.France", OpenStreetMap.HOT = "OpenStreetMap.HOT", 
-    OpenStreetMap.BZH = "OpenStreetMap.BZH", OpenSeaMap = "OpenSeaMap", 
+    OpenStreetMap.BZH = "OpenStreetMap.BZH", MapTilesAPI = "MapTilesAPI", 
+    MapTilesAPI.OSMEnglish = "MapTilesAPI.OSMEnglish", MapTilesAPI.OSMFrancais = "MapTilesAPI.OSMFrancais", 
+    MapTilesAPI.OSMEspagnol = "MapTilesAPI.OSMEspagnol", OpenSeaMap = "OpenSeaMap", 
     OPNVKarte = "OPNVKarte", OpenTopoMap = "OpenTopoMap", OpenRailwayMap = "OpenRailwayMap", 
     OpenFireMap = "OpenFireMap", SafeCast = "SafeCast", Stadia = "Stadia", 
     Stadia.AlidadeSmooth = "Stadia.AlidadeSmooth", Stadia.AlidadeSmoothDark = "Stadia.AlidadeSmoothDark", 
     Stadia.OSMBright = "Stadia.OSMBright", Stadia.Outdoors = "Stadia.Outdoors", 
+    Stadia.StamenToner = "Stadia.StamenToner", Stadia.StamenTonerBackground = "Stadia.StamenTonerBackground", 
+    Stadia.StamenTonerLines = "Stadia.StamenTonerLines", Stadia.StamenTonerLabels = "Stadia.StamenTonerLabels", 
+    Stadia.StamenTonerLite = "Stadia.StamenTonerLite", Stadia.StamenWatercolor = "Stadia.StamenWatercolor", 
+    Stadia.StamenTerrain = "Stadia.StamenTerrain", Stadia.StamenTerrainBackground = "Stadia.StamenTerrainBackground", 
+    Stadia.StamenTerrainLabels = "Stadia.StamenTerrainLabels", 
+    Stadia.StamenTerrainLines = "Stadia.StamenTerrainLines", 
     Thunderforest = "Thunderforest", Thunderforest.OpenCycleMap = "Thunderforest.OpenCycleMap", 
     Thunderforest.Transport = "Thunderforest.Transport", Thunderforest.TransportDark = "Thunderforest.TransportDark", 
     Thunderforest.SpinalMap = "Thunderforest.SpinalMap", Thunderforest.Landscape = "Thunderforest.Landscape", 
     Thunderforest.Outdoors = "Thunderforest.Outdoors", Thunderforest.Pioneer = "Thunderforest.Pioneer", 
     Thunderforest.MobileAtlas = "Thunderforest.MobileAtlas", 
     Thunderforest.Neighbourhood = "Thunderforest.Neighbourhood", 
-    CyclOSM = "CyclOSM", Hydda = "Hydda", Hydda.Full = "Hydda.Full", 
-    Hydda.Base = "Hydda.Base", Hydda.RoadsAndLabels = "Hydda.RoadsAndLabels", 
-    Jawg = "Jawg", Jawg.Streets = "Jawg.Streets", Jawg.Terrain = "Jawg.Terrain", 
-    Jawg.Sunny = "Jawg.Sunny", Jawg.Dark = "Jawg.Dark", Jawg.Light = "Jawg.Light", 
-    Jawg.Matrix = "Jawg.Matrix", MapBox = "MapBox", MapTiler = "MapTiler", 
-    MapTiler.Streets = "MapTiler.Streets", MapTiler.Basic = "MapTiler.Basic", 
-    MapTiler.Bright = "MapTiler.Bright", MapTiler.Pastel = "MapTiler.Pastel", 
-    MapTiler.Positron = "MapTiler.Positron", MapTiler.Hybrid = "MapTiler.Hybrid", 
-    MapTiler.Toner = "MapTiler.Toner", MapTiler.Topo = "MapTiler.Topo", 
-    MapTiler.Voyager = "MapTiler.Voyager", Stamen = "Stamen", 
-    Stamen.Toner = "Stamen.Toner", Stamen.TonerBackground = "Stamen.TonerBackground", 
-    Stamen.TonerHybrid = "Stamen.TonerHybrid", Stamen.TonerLines = "Stamen.TonerLines", 
-    Stamen.TonerLabels = "Stamen.TonerLabels", Stamen.TonerLite = "Stamen.TonerLite", 
-    Stamen.Watercolor = "Stamen.Watercolor", Stamen.Terrain = "Stamen.Terrain", 
-    Stamen.TerrainBackground = "Stamen.TerrainBackground", Stamen.TerrainLabels = "Stamen.TerrainLabels", 
-    Stamen.TopOSMRelief = "Stamen.TopOSMRelief", Stamen.TopOSMFeatures = "Stamen.TopOSMFeatures", 
+    CyclOSM = "CyclOSM", Jawg = "Jawg", Jawg.Streets = "Jawg.Streets", 
+    Jawg.Terrain = "Jawg.Terrain", Jawg.Sunny = "Jawg.Sunny", 
+    Jawg.Dark = "Jawg.Dark", Jawg.Light = "Jawg.Light", Jawg.Matrix = "Jawg.Matrix", 
+    MapBox = "MapBox", MapTiler = "MapTiler", MapTiler.Streets = "MapTiler.Streets", 
+    MapTiler.Basic = "MapTiler.Basic", MapTiler.Bright = "MapTiler.Bright", 
+    MapTiler.Pastel = "MapTiler.Pastel", MapTiler.Positron = "MapTiler.Positron", 
+    MapTiler.Hybrid = "MapTiler.Hybrid", MapTiler.Toner = "MapTiler.Toner", 
+    MapTiler.Topo = "MapTiler.Topo", MapTiler.Voyager = "MapTiler.Voyager", 
     TomTom = "TomTom", TomTom.Basic = "TomTom.Basic", TomTom.Hybrid = "TomTom.Hybrid", 
     TomTom.Labels = "TomTom.Labels", Esri = "Esri", Esri.WorldStreetMap = "Esri.WorldStreetMap", 
     Esri.DeLorme = "Esri.DeLorme", Esri.WorldTopoMap = "Esri.WorldTopoMap", 
@@ -89,8 +89,9 @@ providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "
     BasemapAT.surface = "BasemapAT.surface", BasemapAT.highdpi = "BasemapAT.highdpi", 
     BasemapAT.orthofoto = "BasemapAT.orthofoto", nlmaps = "nlmaps", 
     nlmaps.standaard = "nlmaps.standaard", nlmaps.pastel = "nlmaps.pastel", 
-    nlmaps.grijs = "nlmaps.grijs", nlmaps.luchtfoto = "nlmaps.luchtfoto", 
-    NASAGIBS = "NASAGIBS", NASAGIBS.ModisTerraTrueColorCR = "NASAGIBS.ModisTerraTrueColorCR", 
+    nlmaps.grijs = "nlmaps.grijs", nlmaps.water = "nlmaps.water", 
+    nlmaps.luchtfoto = "nlmaps.luchtfoto", NASAGIBS = "NASAGIBS", 
+    NASAGIBS.ModisTerraTrueColorCR = "NASAGIBS.ModisTerraTrueColorCR", 
     NASAGIBS.ModisTerraBands367CR = "NASAGIBS.ModisTerraBands367CR", 
     NASAGIBS.ViirsEarthAtNight2012 = "NASAGIBS.ViirsEarthAtNight2012", 
     NASAGIBS.ModisTerraLSTDay = "NASAGIBS.ModisTerraLSTDay", 
@@ -119,12 +120,15 @@ providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "
     AzureMaps.MicrosoftBaseHybridRoad = "AzureMaps.MicrosoftBaseHybridRoad", 
     AzureMaps.MicrosoftTerraMain = "AzureMaps.MicrosoftTerraMain", 
     AzureMaps.MicrosoftWeatherInfraredMain = "AzureMaps.MicrosoftWeatherInfraredMain", 
-    AzureMaps.MicrosoftWeatherRadarMain = "AzureMaps.MicrosoftWeatherRadarMain")
+    AzureMaps.MicrosoftWeatherRadarMain = "AzureMaps.MicrosoftWeatherRadarMain", 
+    SwissFederalGeoportal = "SwissFederalGeoportal", SwissFederalGeoportal.NationalMapColor = "SwissFederalGeoportal.NationalMapColor", 
+    SwissFederalGeoportal.NationalMapGrey = "SwissFederalGeoportal.NationalMapGrey", 
+    SwissFederalGeoportal.SWISSIMAGE = "SwissFederalGeoportal.SWISSIMAGE")
 
-providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png", 
+providers_details_data <- list(OpenStreetMap = list(url = "https://tile.openstreetmap.org/{z}/{x}/{y}.png", 
     options = list(maxZoom = 19L, attribution = "&copy; <a href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors"), 
     variants = list(Mapnik = structure(list(), names = character(0)), 
-        DE = list(url = "https://{s}.tile.openstreetmap.de/tiles/osmde/{z}/{x}/{y}.png", 
+        DE = list(url = "https://tile.openstreetmap.de/{z}/{x}/{y}.png", 
             options = list(maxZoom = 18L)), CH = list(url = "https://tile.osm.ch/switzerland/{z}/{x}/{y}.png", 
             options = list(maxZoom = 18L, bounds = structure(c(45L, 
             48L, 5L, 11L), dim = c(2L, 2L)))), France = list(
@@ -135,7 +139,13 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
         BZH = list(url = "https://tile.openstreetmap.bzh/br/{z}/{x}/{y}.png", 
             options = list(attribution = "{attribution.OpenStreetMap}, Tiles courtesy of <a href=\"http://www.openstreetmap.bzh/\" target=\"_blank\">Breton OpenStreetMap Team</a>", 
                 bounds = structure(c(46.2, 50, -5.5, 0.7), dim = c(2L, 
-                2L)))))), OpenSeaMap = list(url = "https://tiles.openseamap.org/seamark/{z}/{x}/{y}.png", 
+                2L)))))), MapTilesAPI = list(url = "https://maptiles.p.rapidapi.com/{variant}/{z}/{x}/{y}.png?rapidapi-key={apikey}", 
+    options = list(attribution = "&copy; <a href=\"http://www.maptilesapi.com/\">MapTiles API</a>, {attribution.OpenStreetMap}", 
+        variant = "en/map/v1", apikey = "<insert your api key here>", 
+        maxZoom = 19L), variants = list(OSMEnglish = list(options = list(
+        variant = "en/map/v1")), OSMFrancais = list(options = list(
+        variant = "fr/map/v1")), OSMEspagnol = list(options = list(
+        variant = "es/map/v1")))), OpenSeaMap = list(url = "https://tiles.openseamap.org/seamark/{z}/{x}/{y}.png", 
     options = list(attribution = "Map data: &copy; <a href=\"http://www.openseamap.org\">OpenSeaMap</a> contributors")), 
     OPNVKarte = list(url = "https://tileserver.memomaps.de/tilegen/{z}/{x}/{y}.png", 
         options = list(maxZoom = 18L, attribution = "Map <a href=\"https://memomaps.de/\">memomaps.de</a> <a href=\"http://creativecommons.org/licenses/by-sa/2.0/\">CC-BY-SA</a>, map data {attribution.OpenStreetMap}")), 
@@ -147,13 +157,36 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
         options = list(maxZoom = 19L, attribution = "Map data: {attribution.OpenStreetMap} | Map style: &copy; <a href=\"http://www.openfiremap.org\">OpenFireMap</a> (<a href=\"https://creativecommons.org/licenses/by-sa/3.0/\">CC-BY-SA</a>)")), 
     SafeCast = list(url = "https://s3.amazonaws.com/te512.safecast.org/{z}/{x}/{y}.png", 
         options = list(maxZoom = 16L, attribution = "Map data: {attribution.OpenStreetMap} | Map style: &copy; <a href=\"https://blog.safecast.org/about/\">SafeCast</a> (<a href=\"https://creativecommons.org/licenses/by-sa/3.0/\">CC-BY-SA</a>)")), 
-    Stadia = list(url = "https://tiles.stadiamaps.com/tiles/alidade_smooth/{z}/{x}/{y}{r}.png", 
-        options = list(maxZoom = 20L, attribution = "&copy; <a href=\"https://stadiamaps.com/\">Stadia Maps</a>, &copy; <a href=\"https://openmaptiles.org/\">OpenMapTiles</a> &copy; <a href=\"http://openstreetmap.org\">OpenStreetMap</a> contributors"), 
-        variants = list(AlidadeSmooth = list(url = "https://tiles.stadiamaps.com/tiles/alidade_smooth/{z}/{x}/{y}{r}.png"), 
-            AlidadeSmoothDark = list(url = "https://tiles.stadiamaps.com/tiles/alidade_smooth_dark/{z}/{x}/{y}{r}.png"), 
-            OSMBright = list(url = "https://tiles.stadiamaps.com/tiles/osm_bright/{z}/{x}/{y}{r}.png"), 
-            Outdoors = list(url = "https://tiles.stadiamaps.com/tiles/outdoors/{z}/{x}/{y}{r}.png"))), 
-    Thunderforest = list(url = "https://{s}.tile.thunderforest.com/{variant}/{z}/{x}/{y}.png?apikey={apikey}", 
+    Stadia = list(url = "https://tiles.stadiamaps.com/tiles/{variant}/{z}/{x}/{y}{r}.{ext}", 
+        options = list(minZoom = 0L, maxZoom = 20L, attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+            variant = "alidade_smooth", ext = "png"), variants = list(
+            AlidadeSmooth = "alidade_smooth", AlidadeSmoothDark = "alidade_smooth_dark", 
+            OSMBright = "osm_bright", Outdoors = "outdoors", 
+            StamenToner = list(options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                variant = "stamen_toner")), StamenTonerBackground = list(
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_toner_background")), StamenTonerLines = list(
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_toner_lines")), StamenTonerLabels = list(
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_toner_labels")), StamenTonerLite = list(
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_toner_lite")), StamenWatercolor = list(
+                url = "https://tiles.stadiamaps.com/tiles/{variant}/{z}/{x}/{y}.{ext}", 
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_watercolor", ext = "jpg", 
+                  minZoom = 1L, maxZoom = 16L)), StamenTerrain = list(
+                options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                  variant = "stamen_terrain", minZoom = 0L, maxZoom = 18L)), 
+            StamenTerrainBackground = list(options = list(attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                variant = "stamen_terrain_background", minZoom = 0L, 
+                maxZoom = 18L)), StamenTerrainLabels = list(options = list(
+                attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                variant = "stamen_terrain_labels", minZoom = 0L, 
+                maxZoom = 18L)), StamenTerrainLines = list(options = list(
+                attribution = "&copy; <a href=\"https://www.stadiamaps.com/\" target=\"_blank\">Stadia Maps</a> &copy; <a href=\"https://www.stamen.com/\" target=\"_blank\">Stamen Design</a> &copy; <a href=\"https://openmaptiles.org/\" target=\"_blank\">OpenMapTiles</a> {attribution.OpenStreetMap}", 
+                variant = "stamen_terrain_lines", minZoom = 0L, 
+                maxZoom = 18L)))), Thunderforest = list(url = "https://{s}.tile.thunderforest.com/{variant}/{z}/{x}/{y}.png?apikey={apikey}", 
         options = list(attribution = "&copy; <a href=\"http://www.thunderforest.com/\">Thunderforest</a>, {attribution.OpenStreetMap}", 
             variant = "cycle", apikey = "<insert your api key here>", 
             maxZoom = 22L), variants = list(OpenCycleMap = "cycle", 
@@ -164,9 +197,6 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
             MobileAtlas = "mobile-atlas", Neighbourhood = "neighbourhood")), 
     CyclOSM = list(url = "https://{s}.tile-cyclosm.openstreetmap.fr/cyclosm/{z}/{x}/{y}.png", 
         options = list(maxZoom = 20L, attribution = "<a href=\"https://github.com/cyclosm/cyclosm-cartocss-style/releases\" title=\"CyclOSM - Open Bicycle render\">CyclOSM</a> | Map data: {attribution.OpenStreetMap}")), 
-    Hydda = list(url = "https://{s}.tile.openstreetmap.se/hydda/{variant}/{z}/{x}/{y}.png", 
-        options = list(maxZoom = 20L, variant = "full", attribution = "Tiles courtesy of <a href=\"http://openstreetmap.se/\" target=\"_blank\">OpenStreetMap Sweden</a> &mdash; Map data {attribution.OpenStreetMap}"), 
-        variants = list(Full = "full", Base = "base", RoadsAndLabels = "roads_and_labels")), 
     Jawg = list(url = "https://{s}.tile.jawg.io/{variant}/{z}/{x}/{y}{r}.png?access-token={accessToken}", 
         options = list(attribution = "<a href=\"http://jawg.io\" title=\"Tiles Courtesy of Jawg Maps\" target=\"_blank\">&copy; <b>Jawg</b>Maps</a> {attribution.OpenStreetMap}", 
             minZoom = 0L, maxZoom = 22L, subdomains = "abcd", 
@@ -185,29 +215,8 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
             Basic = "basic", Bright = "bright", Pastel = "pastel", 
             Positron = "positron", Hybrid = list(options = list(
                 variant = "hybrid", ext = "jpg")), Toner = "toner", 
-            Topo = "topo", Voyager = "voyager")), Stamen = list(
-        url = "https://stamen-tiles-{s}.a.ssl.fastly.net/{variant}/{z}/{x}/{y}{r}.{ext}", 
-        options = list(attribution = "Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> &mdash; Map data {attribution.OpenStreetMap}", 
-            subdomains = "abcd", minZoom = 0L, maxZoom = 20L, 
-            variant = "toner", ext = "png"), variants = list(
-            Toner = "toner", TonerBackground = "toner-background", 
-            TonerHybrid = "toner-hybrid", TonerLines = "toner-lines", 
-            TonerLabels = "toner-labels", TonerLite = "toner-lite", 
-            Watercolor = list(url = "https://stamen-tiles-{s}.a.ssl.fastly.net/{variant}/{z}/{x}/{y}.{ext}", 
-                options = list(variant = "watercolor", ext = "jpg", 
-                  minZoom = 1L, maxZoom = 16L)), Terrain = list(
-                options = list(variant = "terrain", minZoom = 0L, 
-                  maxZoom = 18L)), TerrainBackground = list(options = list(
-                variant = "terrain-background", minZoom = 0L, 
-                maxZoom = 18L)), TerrainLabels = list(options = list(
-                variant = "terrain-labels", minZoom = 0L, maxZoom = 18L)), 
-            TopOSMRelief = list(url = "https://stamen-tiles-{s}.a.ssl.fastly.net/{variant}/{z}/{x}/{y}.{ext}", 
-                options = list(variant = "toposm-color-relief", 
-                  ext = "jpg", bounds = structure(c(22L, 51L, 
-                  -132L, -56L), dim = c(2L, 2L)))), TopOSMFeatures = list(
-                options = list(variant = "toposm-features", bounds = structure(c(22L, 
-                51L, -132L, -56L), dim = c(2L, 2L)), opacity = 0.9)))), 
-    TomTom = list(url = "https://{s}.api.tomtom.com/map/1/tile/{variant}/{style}/{z}/{x}/{y}.{ext}?key={apikey}", 
+            Topo = "topo", Voyager = "voyager")), TomTom = list(
+        url = "https://{s}.api.tomtom.com/map/1/tile/{variant}/{style}/{z}/{x}/{y}.{ext}?key={apikey}", 
         options = list(variant = "basic", maxZoom = 22L, attribution = "<a href=\"https://tomtom.com\" target=\"_blank\">&copy;  1992 - 2023 TomTom.</a> ", 
             subdomains = "abcd", style = "main", ext = "png", 
             apikey = "<insert your API key here>"), variants = list(
@@ -228,7 +237,7 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
                 maxZoom = 13L, attribution = "{attribution.Esri} &mdash; Source: Esri")), 
             WorldPhysical = list(options = list(variant = "World_Physical_Map", 
                 maxZoom = 8L, attribution = "{attribution.Esri} &mdash; Source: US National Park Service")), 
-            OceanBasemap = list(options = list(variant = "Ocean_Basemap", 
+            OceanBasemap = list(options = list(variant = "Ocean/World_Ocean_Base", 
                 maxZoom = 13L, attribution = "{attribution.Esri} &mdash; Sources: GEBCO, NOAA, CHS, OSU, UNH, CSUMB, National Geographic, DeLorme, NAVTEQ, and Esri")), 
             NatGeoWorldMap = list(options = list(variant = "NatGeo_World_Map", 
                 maxZoom = 16L, attribution = "{attribution.Esri} &mdash; National Geographic, Esri, DeLorme, NAVTEQ, UNEP-WCMC, USGS, NASA, ESA, METI, NRCAN, GEBCO, NOAA, iPC")), 
@@ -307,7 +316,7 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
         url = "https://{s}.freemap.sk/T/{z}/{x}/{y}.jpeg", options = list(
             minZoom = 8L, maxZoom = 16L, subdomains = "abcd", 
             bounds = structure(c(47.204642, 49.830896, 15.996093, 
-            22.576904), dim = c(2L, 2L)), attribution = "{attribution.OpenStreetMap}, vizualization CC-By-SA 2.0 <a href=\"http://freemap.sk\">Freemap.sk</a>")), 
+            22.576904), dim = c(2L, 2L)), attribution = "{attribution.OpenStreetMap}, visualization CC-By-SA 2.0 <a href=\"http://freemap.sk\">Freemap.sk</a>")), 
     MtbMap = list(url = "http://tile.mtbmap.cz/mtbmap_tiles/{z}/{x}/{y}.png", 
         options = list(attribution = "{attribution.OpenStreetMap} &amp; USGS")), 
     CartoDB = list(url = "https://{s}.basemaps.cartocdn.com/{variant}/{z}/{x}/{y}{r}.png", 
@@ -324,24 +333,24 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
             variant = "hikebike"), variants = list(HikeBike = structure(list(), names = character(0)), 
             HillShading = list(options = list(maxZoom = 15L, 
                 variant = "hillshading")))), BasemapAT = list(
-        url = "https://maps{s}.wien.gv.at/basemap/{variant}/{type}/google3857/{z}/{y}/{x}.{format}", 
+        url = "https://mapsneu.wien.gv.at/basemap/{variant}/{type}/google3857/{z}/{y}/{x}.{format}", 
         options = list(maxZoom = 19L, attribution = "Datenquelle: <a href=\"https://www.basemap.at\">basemap.at</a>", 
-            subdomains = c("", "1", "2", "3", "4"), type = "normal", 
-            format = "png", bounds = structure(c(46.35877, 49.037872, 
-            8.782379, 17.189532), dim = c(2L, 2L)), variant = "geolandbasemap"), 
-        variants = list(basemap = list(options = list(maxZoom = 20L, 
-            variant = "geolandbasemap")), grau = "bmapgrau", 
-            overlay = "bmapoverlay", terrain = list(options = list(
-                variant = "bmapgelaende", type = "grau", format = "jpeg")), 
-            surface = list(options = list(variant = "bmapoberflaeche", 
-                type = "grau", format = "jpeg")), highdpi = list(
-                options = list(variant = "bmaphidpi", format = "jpeg")), 
-            orthofoto = list(options = list(maxZoom = 20L, variant = "bmaporthofoto30cm", 
-                format = "jpeg")))), nlmaps = list(url = "https://geodata.nationaalgeoregister.nl/tiles/service/wmts/{variant}/EPSG:3857/{z}/{x}/{y}.png", 
+            type = "normal", format = "png", bounds = structure(c(46.35877, 
+            49.037872, 8.782379, 17.189532), dim = c(2L, 2L)), 
+            variant = "geolandbasemap"), variants = list(basemap = list(
+            options = list(maxZoom = 20L, variant = "geolandbasemap")), 
+            grau = "bmapgrau", overlay = "bmapoverlay", terrain = list(
+                options = list(variant = "bmapgelaende", type = "grau", 
+                  format = "jpeg")), surface = list(options = list(
+                variant = "bmapoberflaeche", type = "grau", format = "jpeg")), 
+            highdpi = list(options = list(variant = "bmaphidpi", 
+                format = "jpeg")), orthofoto = list(options = list(
+                maxZoom = 20L, variant = "bmaporthofoto30cm", 
+                format = "jpeg")))), nlmaps = list(url = "https://service.pdok.nl/brt/achtergrondkaart/wmts/v2_0/{variant}/EPSG:3857/{z}/{x}/{y}.png", 
         options = list(minZoom = 6L, maxZoom = 19L, bounds = structure(c(50.5, 
         54, 3.25, 7.6), dim = c(2L, 2L)), attribution = "Kaartgegevens &copy; <a href=\"https://www.kadaster.nl\">Kadaster</a>"), 
-        variants = list(standaard = "brtachtergrondkaart", pastel = "brtachtergrondkaartpastel", 
-            grijs = "brtachtergrondkaartgrijs", luchtfoto = list(
+        variants = list(standaard = "standaard", pastel = "pastel", 
+            grijs = "grijs", water = "water", luchtfoto = list(
                 url = "https://service.pdok.nl/hwh/luchtfotorgb/wmts/v1_0/Actueel_ortho25/EPSG:3857/{z}/{x}/{y}.jpeg"))), 
     NASAGIBS = list(url = "https://map1.vis.earthdata.nasa.gov/wmts-webmerc/{variant}/default/{time}/{tilematrixset}{maxZoom}/{z}/{y}/{x}.{format}", 
         options = list(attribution = "Imagery provided by services from the Global Imagery Browse Services (GIBS), operated by the NASA/GSFC/Earth Science Data and Information System (<a href=\"https://earthdata.nasa.gov\">ESDIS</a>) with funding provided by NASA/HQ.", 
@@ -405,7 +414,7 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
         options = list(minZoom = 9L, maxZoom = 18L, attribution = "Map data: {attribution.OpenStreetMap} & ODbL, &copy; <a href=\"https://www.opensnowmap.org/iframes/data.html\">www.opensnowmap.org</a> <a href=\"https://creativecommons.org/licenses/by-sa/2.0/\">CC-BY-SA</a>"), 
         variants = list(pistes = "pistes")), AzureMaps = list(
         url = "https://atlas.microsoft.com/map/tile?api-version={apiVersion}&tilesetId={variant}&x={x}&y={y}&zoom={z}&language={language}&subscription-key={subscriptionKey}", 
-        options = list(attribution = "See https://docs.microsoft.com/en-US/rest/api/maps/renderv2/getmaptilepreview for details.", 
+        options = list(attribution = "See https://docs.microsoft.com/en-us/rest/api/maps/render-v2/get-map-tile for details.", 
             apiVersion = "2.0", variant = "microsoft.imagery", 
             subscriptionKey = "<insert your subscription key here>", 
             language = "en-US"), variants = list(MicrosoftImagery = "microsoft.imagery", 
@@ -414,9 +423,17 @@ providers_details_data <- list(OpenStreetMap = list(url = "https://{s}.tile.open
             MicrosoftTerraMain = "microsoft.terra.main", MicrosoftWeatherInfraredMain = list(
                 url = "https://atlas.microsoft.com/map/tile?api-version={apiVersion}&tilesetId={variant}&x={x}&y={y}&zoom={z}&timeStamp={timeStamp}&language={language}&subscription-key={subscriptionKey}", 
                 options = list(timeStamp = "2021-05-08T09:03:00Z", 
-                  attribution = "See https://docs.microsoft.com/en-US/rest/api/maps/renderv2/getmaptilepreview#uri-parameters for details.", 
+                  attribution = "See https://docs.microsoft.com/en-us/rest/api/maps/render-v2/get-map-tile#uri-parameters for details.", 
                   variant = "microsoft.weather.infrared.main")), 
             MicrosoftWeatherRadarMain = list(url = "https://atlas.microsoft.com/map/tile?api-version={apiVersion}&tilesetId={variant}&x={x}&y={y}&zoom={z}&timeStamp={timeStamp}&language={language}&subscription-key={subscriptionKey}", 
                 options = list(timeStamp = "2021-05-08T09:03:00Z", 
-                  attribution = "See https://docs.microsoft.com/en-US/rest/api/maps/renderv2/getmaptilepreview#uri-parameters for details.", 
-                  variant = "microsoft.weather.radar.main")))))
+                  attribution = "See https://docs.microsoft.com/en-us/rest/api/maps/render-v2/get-map-tile#uri-parameters for details.", 
+                  variant = "microsoft.weather.radar.main")))), 
+    SwissFederalGeoportal = list(url = "https://wmts.geo.admin.ch/1.0.0/{variant}/default/current/3857/{z}/{x}/{y}.jpeg", 
+        options = list(attribution = "&copy; <a href=\"https://www.swisstopo.admin.ch/\">swisstopo</a>", 
+            minZoom = 2L, maxZoom = 18L, bounds = structure(c(45.398181, 
+            48.230651, 5.140242, 11.47757), dim = c(2L, 2L))), 
+        variants = list(NationalMapColor = "ch.swisstopo.pixelkarte-farbe", 
+            NationalMapGrey = "ch.swisstopo.pixelkarte-grau", 
+            SWISSIMAGE = list(options = list(variant = "ch.swisstopo.swissimage", 
+                maxZoom = 19L)))))
